from __future__ import print_function

import datetime

def generate_snapshot_version(src_repo_reltag, src_repo_type, src_repo_rev, src_repo_branch, spec_rev_form):

    # Check for valid revision form value
    spec_rev_forms = [ "postrel", "prerel" ]

    if spec_rev_form not in spec_rev_forms:
        raise ValueError("Invalid snapshot version form type")

    # Validate the VCS type
    vcs_types = [ "git", "hg", "svn" ]
    if src_repo_type not in vcs_types:
        raise ValueError("Invalid version control system type")

    # Generate a short hash for hg/git, reuse rev for subversion
    if src_repo_type == "git" or src_repo_type == "hg":
        repo_tag_shorthash = src_repo_rev[:7]
    else:
        repo_tag_shorthash = src_repo_rev

    # Generate the datetime stamp for the build
    pkg_build_datetime = datetime.datetime.now()

    pkg_build_date = "{0}{1}{2}".format(pkg_build_datetime.year,
                                        pkg_build_datetime.month,
                                        pkg_build_datetime.day)
    pkg_build_time = "{0}{1}".format(pkg_build_datetime.hour,
                                     pkg_build_datetime.minute)
    # pkg_build_time = "{0}{1}{2}".format(pkg_build_datetime.hour, pkg_build_datetime.minute, pkg_build_datetime.second)

    # Configure version form
    # 0: Version, 1: VCS, 2: Build date, 3: build time, 4: VCS revision

    if spec_rev_form == "postrel":
        spec_ver_form = "{0}+{1}{2}{3}.{4}.{5}"
    elif spec_rev_form == "prerel":
        spec_ver_form = "{0}.0.1~{1}{2}{3}.{4}.{5}"
    else:
        spec_ver_form = "{0}.{1}{2}{3}.{4}.{5}"

    return spec_ver_form.format(src_repo_reltag, src_repo_type,
                                pkg_build_date, pkg_build_time,
                                repo_tag_shorthash, src_repo_branch
                                .replace('-', '').replace('_', '').lower())
