import os
import shutil
import tarfile
import tempfile


def rebuild_tarball(src_tarball, src_name, version):
    # Pull out original sources to tarfix_dir
    orig_tarball = tarfile.open(name=src_tarball, mode="r:gz")
    tarfix_dir = tempfile.mkdtemp(suffix="tarfix")
    orig_tarball.extractall(path=tarfix_dir)
    orig_tarball.close()

    # Generate new tarball working area
    new_tgz_dir = tempfile.mkdtemp(suffix="newtgz")

    # Make new tarball name
    rebuilt_tarball_prefix = "{0}-{1}".format(src_name,
                                              version)

    rebuilt_tarball_name = "{0}.tar.gz".format(rebuilt_tarball_prefix)

    # Move the files to the new working area
    shutil.move("{0}/{1}".format(tarfix_dir, src_name),
                "{0}/{1}-{2}".format(tarfix_dir, src_name, version))

    # Generate the new tarball
    new_tarball = shutil.make_archive(base_name="{0}/{1}"
                                      .format(new_tgz_dir,
                                              rebuilt_tarball_prefix),
                                      format="gztar",
                                      root_dir=tarfix_dir,
                                      base_dir="./{0}-{1}"
                                      .format(src_name, version))
    # Purge the old working tree
    shutil.rmtree(tarfix_dir)

    return new_tarball
